photosgallery/viewframework/commandhandlers/commoncommandhandlers/inc/glxcommandhandleraiwassign.h
branchRCL_3
changeset 25 191387a8b767
parent 14 ce1c7ad1f18b
--- a/photosgallery/viewframework/commandhandlers/commoncommandhandlers/inc/glxcommandhandleraiwassign.h	Wed Apr 14 15:57:24 2010 +0300
+++ b/photosgallery/viewframework/commandhandlers/commoncommandhandlers/inc/glxcommandhandleraiwassign.h	Tue Apr 27 16:37:53 2010 +0300
@@ -41,17 +41,19 @@
     {
 public:
     /**
      * Two-phase constructor
      * @param aMediaListProvider object that provides the media list
      * @param aMenuResource The menu resource that the AIW command will be 
      *          implented in
      * @return Fully constructed command handler
      * @warning ConstructL of base class is called. If ConstructL is 
      *          implemented in this class, then care must be taken to call 
      *          CGlxCommandHandlerAiwBase::ConstructL
      */
 	IMPORT_C static CGlxCommandHandlerAiwAssign* NewL(
-	    MGlxMediaListProvider* aMediaListProvider, TInt aMenuResource);
+			MGlxMediaListProvider* aMediaListProvider, TInt aMenuResource,
+			const TDesC& aFileName);
 	
 	~CGlxCommandHandlerAiwAssign();
 	
@@ -77,8 +79,10 @@
      */
     CGlxCommandHandlerAiwAssign(MGlxMediaListProvider* aMediaListProvider, 
         TInt aMenuResource);
-    
-    void ConstructL();
+    /**
+     * @param aFileName resource file
+     */
+    void ConstructL(const TDesC& aFileName);
 
 private: // Data Members
@@ -41,17 +41,19 @@
 public:
     /**
-     * Two-phase constructor
-     * @param aMediaListProvider object that provides the media list
-     * @param aMenuResource The menu resource that the AIW command will be 
-     *          implented in
-     * @return Fully constructed command handler
-     * @warning ConstructL of base class is called. If ConstructL is 
-     *          implemented in this class, then care must be taken to call 
-     *          CGlxCommandHandlerAiwBase::ConstructL
-     */
+	 * Two-phase constructor
+	 * @param aMediaListProvider object that provides the media list
+	 * @param aMenuResource The menu resource that the AIW command will be 
+	 *          implented in
+     * @param aFileName resource file
+	 * @return Fully constructed command handler
+	 * @warning ConstructL of base class is called. If ConstructL is 
+	 *          implemented in this class, then care must be taken to call 
+	 *          CGlxCommandHandlerAiwBase::ConstructL
+	 */
 	IMPORT_C static CGlxCommandHandlerAiwAssign* NewL(